# DiskScan

DiskScan is a cross-platform disk cleaner tool that helps you clean temporary files, cache, and log files from your system.

## Installation

Install DiskScan via pip:

pip install diskscan

## Usage

Run DiskScan from the command line:

diskscan scan # For a medium-size scan
diskscan fullscan # For a complete scan
diskscan scango # For a quick scan

## Supported Platforms

- Windows
- MacOS
- Linux
- ChromeOS
